==> legaut-text-annotate-0.0.11.tgz: package/src/Mark.tsx <==
import * as React from 'react';
import { useState } from 'react';
import Popover from 'react-tiny-popover'


export interface MarkProps {
  key: string
  content: string
  start: number
  end: number
  tag: string
  display: string
  wordsToBold?:Array<string>
  special_label?: string
  color?: string
  onClick: (any) => any
  onClickChange: (any) => any
}

const style = {
    //webkitTouchCallout: 'none', /* iOS Safari */
    //webkitUserSelect: 'none', /* Safari */
    //khtmlUserSelect: 'none', /* Konqueror HTML */
    //mozUserSelect: 'none', /* Old versions of Firefox */
    //msUserSelect: 'none', /* Internet Explorer/Edge */
    userSelect: 'none', /* Non-prefixed version, currently
                                  supported by Chrome, Opera and Firefox */
}

const tagSpecial = (special_label,tag) => {
  if(tag === "reference"){
    return `Referência - ${special_label}`;
  }
  if(special_label === "" || special_label === undefined) {
    return tag;
  } else {
    return special_label;
  }
}

const Mark: React.SFC<MarkProps> = props => {
  const buttonStyle = {
    backgroundColor: "white",
    border: "none",
    color: "#000000",
    padding:"5px 5px",
    margin: "3px",
    textAlignProperty: "center",
    textDecoration: "none",
    display: "inline-block",
    fontSize: '10px',
    borderRadius: '4px',
  }

  let bgColor = '#84d2ff';

  if (props.tag === 'reference'){
    bgColor = '#00000057'
  } else if(props.color){
    bgColor = props.color;
  }

  var fore = 'black'

  if(props.color){
    var rgb = [parseInt(props.color.substring(1,3),16),parseInt(props.color.substring(3,5),16),parseInt(props.color.substring(5,7),16)]
    var uicolors = [rgb[0] / 255, rgb[1] / 255, rgb[2] / 255];
    var c = uicolors.map((col) => {
      if (col <= 0.03928) {
        return col / 12.92;
      }
      return Math.pow((col + 0.055) / 1.055, 2.4);
    });
    var L = (0.2126 * c[0]) + (0.7152 * c[1]) + (0.0722 * c[2]);
    fore = (L > 0.179) ? 'black' : 'white';
    console.log(fore)
  }
  
  return (
  <mark
    style={{backgroundColor: bgColor, padding: '0 4px', color: fore }}
    data-start={props.start}
    data-end={props.end}
    onClick={ () => props.onClickChange({start: props.start, end: props.end})}
  >
    {props.content}
    {props.tag && (
      <span style={{fontSize: '0.7em', fontWeight: 500, marginLeft: 6, userSelect: 'none'}}>{tagSpecial(props.special_label,props.tag)}</span>
    )}
  </mark>
)}

export default Mark

==> legaut-text-annotate-0.0.12.tgz: package/src/Mark.tsx <==
import * as React from 'react';
import { useState } from 'react';
import Popover from 'react-tiny-popover'


export interface MarkProps {
  key: string
  content: string
  start: number
  end: number
  tag: string
  display: string
  wordsToBold?:Array<string>
  special_label?: string
  color?: string
  showTags: boolean
  onClick: (any) => any
  onClickChange: (any) => any
}

const style = {
    //webkitTouchCallout: 'none', /* iOS Safari */
    //webkitUserSelect: 'none', /* Safari */
    //khtmlUserSelect: 'none', /* Konqueror HTML */
    //mozUserSelect: 'none', /* Old versions of Firefox */
    //msUserSelect: 'none', /* Internet Explorer/Edge */
    userSelect: 'none', /* Non-prefixed version, currently
                                  supported by Chrome, Opera and Firefox */
}

const tagSpecial = (special_label,tag) => {
  if(tag === "reference"){
    return `Referência - ${special_label}`;
  }
  if(special_label === "" || special_label === undefined) {
    return tag;
  } else {
    return special_label;
  }
}

const Mark: React.SFC<MarkProps> = props => {
  const buttonStyle = {
    backgroundColor: "white",
    border: "none",
    color: "#000000",
    padding:"5px 5px",
    margin: "3px",
    textAlignProperty: "center",
    textDecoration: "none",
    display: "inline-block",
    fontSize: '10px',
    borderRadius: '4px',
  }

  let bgColor = '#84d2ff';

  if (props.tag === 'reference'){
    bgColor = '#00000057'
  } else if(props.color){
    bgColor = props.color;
  }

  var fore = 'black'

  if(props.color){
    var rgb = [parseInt(props.color.substring(1,3),16),parseInt(props.color.substring(3,5),16),parseInt(props.color.substring(5,7),16)]
    var uicolors = [rgb[0] / 255, rgb[1] / 255, rgb[2] / 255];
    var c = uicolors.map((col) => {
      if (col <= 0.03928) {
        return col / 12.92;
      }
      return Math.pow((col + 0.055) / 1.055, 2.4);
    });
    var L = (0.2126 * c[0]) + (0.7152 * c[1]) + (0.0722 * c[2]);
    fore = (L > 0.179) ? 'black' : 'white';
    console.log(fore)
  }
  
  return (
  <mark
    style={{backgroundColor: bgColor, padding: '0 4px', color: fore }}
    data-start={props.start}
    data-end={props.end}
    onClick={ () => props.onClickChange({start: props.start, end: props.end, tag:props.tag, special_label: props.special_label })}
  >
    {props.content}
    {props.showTags && props.tag && (
      <span style={{fontSize: '0.7em', fontWeight: 500, marginLeft: 6, userSelect: 'none'}}>{tagSpecial(props.special_label,props.tag)}</span>
    )}
  </mark>
)}

export default Mark
